==> graveman-0.3.10-2.tar.bz2: graveman-0.3.10/include/images.h <==
/* images.h
 * Copyright (C) 2005 Sylvain Cresto <scresto@gmail.com>
 *
 * This file is part of graveman!
 *
 * graveman! is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or
 * (at your option) any later version.
 * 
 * graveman! is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA. 
 * 
 * URL: http://www.nongnu.org/graveman/
 *
 */

#ifndef _G_IMAGES_H
#define _G_IMAGES_H

extern GdkPixbuf *GDirIcone;
extern GdkPixbuf *GFileIcone;
extern GdkPixbuf *GFileImage;
extern GdkPixbuf *GpetiteGraver;
extern GdkPixbuf *GISOpetiteIcone;
extern GdkPixbuf *GGraver;
extern GdkPixbuf *GEraseCdrw;
extern GdkPixbuf *GCDIcone;
extern GdkPixbuf *GAudioIcone;
extern GdkPixbuf *GCDRWIcone;
extern GdkPixbuf *GMenuAudio;
extern GdkPixbuf *GMenuData;
extern GdkPixbuf *GMenuDvd;
extern GdkPixbuf *GMenuCopy;
extern GdkPixbuf *GMenuOther;
extern GdkPixbuf *GCDpetiteIcone;
extern GdkPixbuf *GCDRWpetiteIcone;
extern GdkPixbuf *GDVDpetiteIcone;
extern GdkPixbuf *GDVDRWpetiteIcone;
extern GdkPixbuf *GcharsetpetiteIcone;
extern GdkPixbuf *GiconeOK;
extern GdkPixbuf *GiconePASOK;
extern GdkPixbuf *GiconeMITIGE;

extern void load_all_images();
extern void free_all_images();
extern void load_menu_images(gchar *Lquel);
extern void prepare_menu_images(Tgrave *Ag);

#endif

/*
 * vim:et:ts=8:sts=2:sw=2
 */

==> graveman-0.3.11.tar.bz2: graveman-0.3.11/include/images.h <==
/* images.h
 * Copyright (C) 2005 Sylvain Cresto <scresto@gmail.com>
 *
 * This file is part of graveman!
 *
 * graveman! is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or
 * (at your option) any later version.
 * 
 * graveman! is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA. 
 * 
 * URL: http://www.nongnu.org/graveman/
 *
 */

#ifndef _G_IMAGES_H
#define _G_IMAGES_H

/* extern GdkPixbuf *GDirIcone;
extern GdkPixbuf *GFileIcone;
extern GdkPixbuf *GFileImage;
extern GdkPixbuf *GpetiteGraver;
extern GdkPixbuf *GISOpetiteIcone;
extern GdkPixbuf *GGraver;
extern GdkPixbuf *GEraseCdrw;
extern GdkPixbuf *GCDIcone;
extern GdkPixbuf *GAudioIcone;
extern GdkPixbuf *GCDRWIcone;
extern GdkPixbuf *GMenuAudio;
extern GdkPixbuf *GMenuData;
extern GdkPixbuf *GMenuDvd;
extern GdkPixbuf *GMenuCopy;
extern GdkPixbuf *GMenuOther;
extern GdkPixbuf *GCDpetiteIcone;
extern GdkPixbuf *GCDRWpetiteIcone;
extern GdkPixbuf *GDVDpetiteIcone;
extern GdkPixbuf *GDVDRWpetiteIcone;
extern GdkPixbuf *GcharsetpetiteIcone;
extern GdkPixbuf *GiconeOK;
extern GdkPixbuf *GiconePASOK;
extern GdkPixbuf *GiconeMITIGE; */

#define _IMG_PNG 0
#define _IMG_MNG 1

extern gboolean load_all_images();
extern void free_all_images();
extern gboolean load_menu_images(gchar *Lquel);
extern gboolean prepare_menu_images(Tgrave *Ag);
extern GdkPixbuf *get_image(gchar *Aident);
extern gchar *get_animation(gchar *Aident);

#endif

/*
 * vim:et:ts=8:sts=2:sw=2
 */
